#ifndef s11n_addon_PSTREAMS_CURL_HPP_INCLUDED
#define s11n_addon_PSTREAMS_CURL_HPP_INCLUDED 1

#include <string>
#include <s11n.net/s11n/io/url.hpp>
#include <s11n.net/s11n/export.hpp>
#include "license_lgpl.hpp"

namespace s11n { namespace io { namespace pstreams {


	/**
	   This factory creates streams for URLs in the following format:

	   [ftp|http]://[user[:password]@]host[:port]/path/to/file

	   It works only for input, not output.

	   Requires that 'curl' is in your $PATH.
	*/
	class S11N_EXPORT_API curl_stream_factory : public ::s11n::io::url_stream_factory
	{
	public:
		curl_stream_factory();
		virtual ~curl_stream_factory();

	protected:
		/** Always returns 0. This factory cannot create writeable streams. */
		virtual std::ostream * do_get_ostream( ::s11n::io::url_parser const & url ) const;

		/**
		   Returns a stream which reads from url using curl.

		   The caller owns the returned pointer, which may be 0.
		 */
		virtual std::istream * do_get_istream( ::s11n::io::url_parser const & url ) const;
	};


} } } // namespaces



#endif // s11n_addon_PSTREAMS_CURL_HPP_INCLUDED
